maximum_length

Function maximum_length 

pub(crate) fn maximum_length(key: &CryptoKey) -> Result<u32, Error>
Given an elliptic curve key, returns the length in bits of the output of the field element to octet string conversion defined in Section 6.2 of [RFC6090] for the EC domain parameters associated with key.